pub enum DerefError {
IriSError(IriSError),
DerefPrefixMapError {
alias: String,
local: String,
error: Box<PrefixMapError>,
},
NoPrefixMapPrefixedName {
prefix: String,
local: String,
},
UnderefError(IriRefError),
}Expand description
Represents all the possible errors that can occur when dereferencing IRIs
Variants
IriSError(IriSError)
An error originating from the iri_s crate
DerefPrefixMapError
An error originating when obtaining an IRI from a PrefixMap
Fields
error: The underlyingPrefixMapError
NoPrefixMapPrefixedName
An error occured when trying to dereference a prefixed name without a prefix map
UnderefError(IriRefError)
An error occured when trying to obtain an IRI from an [IriRef]