pub enum PrefixMapError {
IriSError(IriSError),
PrefixNotFound {
prefix: String,
prefixmap: PrefixMap,
},
FormatError(Error),
IOError {
error: String,
},
AliasAlreadyExists {
prefix: String,
value: String,
},
}Expand description
Errors that can occur when working with PrefixMap
Variants
IriSError(IriSError)
Error originating from the iri_s crate
PrefixNotFound
Error indicating that a requested prefix alias was not found in the PrefixMap
FormatError(Error)
Error indicating a formatting issue
IOError
Error indicating an IO issue
AliasAlreadyExists
Error indicating that an alias already exists in the PrefixMap